#
# spec file for package python-pylama
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pylama
Version:        8.4.1
Release:        3.5
Summary:        Code audit tool for python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/klen/pylama
Source:         https://github.com/klen/pylama/archive/refs/tags/%{version}.tar.gz#/pylama-%{version}-gh.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module mccabe      >= 0.7.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pycodestyle >= 2.9.1}
BuildRequires:  %{python_module pydocstyle  >= 6.1.1}
BuildRequires:  %{python_module pyflakes    >= 2.5.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  git-core
%if 0%{?suse_version} > 1500
BuildRequires:  mypy
%endif
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
Requires:       python-mccabe      >= 0.7.0
Requires:       python-pycodestyle >= 2.9.1
Requires:       python-pydocstyle  >= 6.1.1
Requires:       python-pyflakes    >= 2.5.0
Suggests:       python-pylint
Suggests:       python-eradicate
Suggests:       python-radon
Suggests:       python-mypy
Suggests:       python-vulture
Recommends:     python-toml >= 0.10.2
# SECTION test
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module eradicate >= 2}
BuildRequires:  %{python_module mypy}
BuildRequires:  %{python_module pylint >= 2.11.1}
BuildRequires:  %{python_module radon >= 5.1.0}
BuildRequires:  %{python_module toml >= 0.10.2}
BuildRequires:  %{python_module vulture}
# /SECTION
BuildArch:      noarch
%python_subpackages

%description
Code audit tool for Python. Pylama wraps these tools:

- pycodestyle (formerly pep8) © 2012-2013, Florent Xicluna;
- pydocstyle (formerly pep257 by Vladimir Keleshev) © 2014, Amir Rachum;
- PyFlakes © 2005-2013, Kevin Watters;
- Mccabe © Ned Batchelder;
- Pylint © 2013, Logilab;
- Radon © Michele Lacchia
- eradicate © Steven Myint;
- Mypy © Jukka Lehtosalo and contributors;
- Vulture © Jendrik Seipp and contributors;

%prep
%autosetup -p1 -n pylama-%{version}

%build
export LANG=en_US.UTF-8
%pyproject_wheel

%install
export LANG=en_US.UTF-8
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pylama
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
# pylama-quotes is on PyPI but has no active Website or repository for code maintenance
donttest="test_quotes"
# gh#klen/pylama#238
donttest+=" or test_pylint"
%pytest -k "not ($donttest)"

%post
%python_install_alternative pylama

%postun
%python_uninstall_alternative pylama

%files %{python_files}
%doc Changelog README.rst
%license LICENSE
%python_alternative %{_bindir}/pylama
%{python_sitelib}/pylama
%{python_sitelib}/pylama-%{version}*-info

%changelog
* Tue Jun 13 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu May 11 2023 Ben Greiner <code@bnavigator.de>
- Skip failing pylint test: pylint has advanced, but pylama is not
  maintained at the moment -- gh#klen/pylama#238
* Thu Aug 25 2022 Ben Greiner <code@bnavigator.de>
- Update to 8.4.1
  * Support TOML configuration (thank you
    https://github.com/villainy)
  * Fix pylint integration
  * Fix linting for empty files
- Version 8.3.8
  * Better pytest integration
- Version 8.3.6
  * Fixed processing of linters params
- Version 8.3.0
  * Added support for default config file `~/.pylama.ini`
- Version 8.2.0
  * Added `--max-line-length` to setup max line length for
    pycodestyle and pylint
  * Support for linters options in command line
- Version 8.1.4
  * Support json format
  * Support `--from-stdin` option
  * Changed: pylama only allows to check python files (--force is
    removed)
  * Changed: mccabe argument `complexity` -> `max-complexity`
- Version 8.0.5
  * Drop support for python 2
  * Support python 3.7, 3.8, 3.9
  * Support mccabe==0.6.1, pycodestyle==2.8.0, pydocstyle==6.1.1,
    pyflakes==2.4.0, eradicate==2.0.0, radon==5.1.0, pylint==2.11.1
  * Support vulture
  * Support 'convention' for pydocstyle
  * License changed to MIT (see LICENSE file for details)
  * Fix Radon message format
- Drop support-pytest-6.patch
* Wed Aug 10 2022 Dirk Müller <dmueller@suse.com>
- remove unnecessary dependency on pylint
* Tue Mar 16 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add support-pytest-6.patch to support running with pytest >= 6.
* Wed Dec  9 2020 Benjamin Greiner <code@bnavigator.de>
- Skip mypy test for flavors, which do not provide it
  (mypy is optional)
* Tue Sep 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip one test that relies on the number of errors found by
  linters that differ based on the release we got
* Tue May  7 2019 pgajdos@suse.com
- version update to 7.7.1
  * no upstream changelog
- modified sources
  %% dummy.py
* Mon Feb 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to version 7.6.6:
  * various async and tests fixes
  * no actual upstream changelog updated since 7.4 release
- Actually run tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed May  9 2018 toddrme2178@gmail.com
- Use license tag
* Wed Oct 18 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 7.4.3
  * See changelog at https://github.com/klen/pylama/blob/7.4.3/Changelog
* Thu Jul 10 2014 toddrme2178@gmail.com
- Update to 6.0.0
  - No upstream changelog
* Mon Mar 24 2014 toddrme2178@gmail.com
- Initial version
